<?php
namespace Ems\portalGestor\Service;

use Ems\portalGestor\Util\HcmServices;
use Ems\portalGestor\Repository\MinhaHistoriaRepository;

use Ems\portalGestor\Util\DateUtil;


class MinhaHistoriaService {
    /** @var HcmServices */
    protected $hcmServices;

    /** @var MinhaHistoriaRepository */
    protected $minhaHistoriaRepository;

    public function __construct(
        HcmServices $hcmServices,
        MinhaHistoriaRepository $minhaHistoriaRepository
    ) {
        $this->hcmServices              = $hcmServices;
        $this->minhaHistoriaRepository  = $minhaHistoriaRepository;
    }


    public function getDadosPessoais($nrorg, $nrvinculom) {

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRORG'      => $nrorg,
                'NRVINCULOM' => $nrvinculom
            ]
        ];

        $result = $this->hcmServices->send('getPessoa', $params, $nrorg);
        $dadosPessoais = $result['dataset']['getPessoa'];

        return $dadosPessoais;
    }

    public function getComunicacaoParc($nrorg, $nrvinculom) {

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRORG'      => $nrorg,
                'NRVINCULOM' => $nrvinculom
            ]
        ];

        $result = $this->hcmServices->send('getComunicacaoParc', $params, $nrorg);
        $comunicacao = $result['dataset']['getComunicacaoParc'];

        return $comunicacao;
    }
    
    public function getContaCorrenteParc($nrorg, $nrvinculom) {

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRORG'      => $nrorg,
                'NRVINCULOM' => $nrvinculom
            ]
        ];

        $result = $this->hcmServices->send('getContaCorrenteParc', $params, $nrorg);
        $comunicacao = $result['dataset']['getContaCorrenteParc'];

        return $comunicacao;
    }
    
    public function getAdressCEP($nrorg, $cep) {

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRORG'      => $nrorg,
                'CEP' => $cep
            ]
        ];

        $result = $this->hcmServices->send('findAddress', $params, $nrorg);
        $comunicacao = $result['dataset']['ENDERECO'];

        return $comunicacao;
    }
    
    public function getEnderecoParc($nrorg, $nrvinculom) {

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRORG'      => $nrorg,
                'NRVINCULOM' => $nrvinculom
            ]
        ];

        $result = $this->hcmServices->send('getEnderecoParc', $params, $nrorg);
        $endereco = $result['dataset']['getEnderecoParc'];

        return $endereco;
    }

    public function solicitaAlteracao($row) {
        try {
            $params = [
                'requestType' => 'Row',
                'row' => $row
            ];
            
            $result = $this->hcmServices->send('solicitaAlteracao', $params, $row['NRORG']);
            return $result;
		} catch (\Exception $e) {
			throw $e;
		}        
    }

    public function getEstadocivil($nrorg) {
        try {
			return $this->minhaHistoriaRepository->getEstadocivil(
                $nrorg
            );
		} catch (\Exception $e) {
			throw $e;
		}        
    }

    public function getCondicaoFisica($nrorg) {
        try {
			return $this->minhaHistoriaRepository->getCondicaoFisica(
                $nrorg
            );
		} catch (\Exception $e) {
			throw $e;
		}        
    }
    
    public function getRacaPessoa($nrorg) {
        try {
			return $this->minhaHistoriaRepository->getRacaPessoa(
                $nrorg
            );
		} catch (\Exception $e) {
			throw $e;
		}        
    }
    
    public function getGrauinstrucao($nrorg) {
        try {
			return $this->minhaHistoriaRepository->getGrauinstrucao(
                $nrorg
            );
		} catch (\Exception $e) {
			throw $e;
		}        
    }
    
    public function getPais($nrorg) {
        try {
			return $this->minhaHistoriaRepository->getPais(
                $nrorg
            );
		} catch (\Exception $e) {
			throw $e;
		}        
    }
    
    public function getEstado($nrorg) {
        try {
			return $this->minhaHistoriaRepository->getEstado(
                $nrorg
            );
		} catch (\Exception $e) {
			throw $e;
		}        
    }
    
    public function getMunicipio($nrorg, $cdpais, $cdestado) {
        try {
			return $this->minhaHistoriaRepository->getMunicipio(
                $nrorg, $cdpais, $cdestado
            );
		} catch (\Exception $e) {
			throw $e;
		}        
    }
    
    public function getNacionalidade($nrorg) {
        try {
			return $this->minhaHistoriaRepository->getNacionalidade(
                $nrorg
            );
		} catch (\Exception $e) {
			throw $e;
		}        
    }
    
    public function getClasseEstrang($nrorg) {
        try {
			return $this->minhaHistoriaRepository->getClasseEstrang(
                $nrorg
            );
		} catch (\Exception $e) {
			throw $e;
		}        
    }
    
    public function getConselhoRegional($nrorg) {
        try {
			return $this->minhaHistoriaRepository->getConselhoRegional(
                $nrorg
            );
		} catch (\Exception $e) {
			throw $e;
		}        
    }
    
    public function getCategoriaMilitar($nrorg) {
        try {
			return $this->minhaHistoriaRepository->getCategoriaMilitar(
                $nrorg
            );
		} catch (\Exception $e) {
			throw $e;
		}        
    }
    
    public function getBanco($nrorg) {
        try {
			return $this->minhaHistoriaRepository->getBanco(
                $nrorg
            );
		} catch (\Exception $e) {
			throw $e;
		}        
    }
    
    public function getAgencia($nrorg, $cdbanco) {
        try {
			return $this->minhaHistoriaRepository->getAgencia(
                $nrorg, $cdbanco
            );
		} catch (\Exception $e) {
			throw $e;
		}        
    }
    
    public function getTpContaCorrente($nrorg) {
        try {
			return $this->minhaHistoriaRepository->getTpContaCorrente(
                $nrorg
            );
		} catch (\Exception $e) {
			throw $e;
		}        
    }
    
    public function getLogradouro($nrorg) {
        try {
			return $this->minhaHistoriaRepository->getLogradouro(
                $nrorg
            );
		} catch (\Exception $e) {
			throw $e;
		}        
    }
    
    public function getTpEndereco($nrorg) {
        try {
			return $this->minhaHistoriaRepository->getTpEndereco(
                $nrorg
            );
		} catch (\Exception $e) {
			throw $e;
		}        
    }
    
    public function getOperadores($nrorg) {
        try {
			return $this->minhaHistoriaRepository->getOperadores(
                $nrorg
            );
		} catch (\Exception $e) {
			throw $e;
		}        
    }

}
